@@ -1,16 +1,13 @@
 from abc import abstractmethod
-from typing import Any, AsyncIterator, Callable, Dict, List, Union
+from typing import AsyncIterator, List
 
 from launart import Service
 
-from ..const import Api
 from ..model import Event, Login
-from .route import RouteCall, RouterMixin
+from .route import RouterMixin
 
 
 class Adapter(Service, RouterMixin):
-    routes: Dict[str, RouteCall[Any, Any]]
-
     @abstractmethod
     def get_platform(self) -> str: ...
 
@@ -18,24 +15,21 @@ class Adapter(Service, RouterMixin):
     def publisher(self) -> AsyncIterator[Event]: ...
 
     @abstractmethod
-    def validate_headers(self, headers: Dict[str, Any]) -> bool: ...
+    def ensure(self, platform: str, self_id: str) -> bool: ...
 
     @abstractmethod
     def authenticate(self, token: str) -> bool: ...
 
+    @staticmethod
+    def proxy_urls() -> List[str]:
+        return []
+
+    @abstractmethod
+    async def download_uploaded(self, platform: str, self_id: str, path: str) -> bytes: ...
+
     @abstractmethod
     async def get_logins(self) -> List[Login]: ...
 
-    def _route(self, path: Union[str, Api]) -> Callable[[RouteCall], RouteCall]:
-        def wrapper(func: RouteCall):
-            if isinstance(path, Api):
-                self.routes[path.value] = func
-            else:
-                self.routes[f"internal/{path}"] = func
-            return func
-
-        return wrapper
-
     def __init__(self):
         super().__init__()
         self.routes = {}
